import os
import json
from cas import CASClient
from django.conf import settings as django_settings
from six.moves import urllib_parse


def normalize_username(username):
    return username.lower()


def get_protocol(request):
    if request.is_secure() or django_settings.SSO_UI_FORCE_SERVICE_HTTPS:
        return "https"

    return "http"


def get_service_url(request, redirect_to=None):
    protocol = get_protocol(request)
    host = request.get_host()
    service = urllib_parse.urlunparse((protocol, host, request.path, "", "", ""))

    return service


def get_cas_client(service_url=None, request=None):
    server_url = django_settings.SSO_UI_URL
    if server_url and request and server_url.startswith("/"):
        scheme = request.META.get("X-Forwarded-Proto", request.scheme)
        server_url = scheme + "://" + request.META["HTTP_HOST"] + server_url

    return CASClient(service_url=service_url, server_url=server_url, version=2)


def authenticate(ticket, client):
    username, attributes, _ = client.verify_ticket(ticket)

    if not username:
        return None

    if "kd_org" in attributes:
        attributes.update(get_additional_info(attributes["kd_org"]) or {})

    sso_profile = {"username": username, "attributes": attributes}
    return sso_profile


def get_additional_info(kd_org):
    path = os.path.dirname(os.path.abspath(__file__))
    filename = os.path.join(path, "additional-info.json")

    with open(filename, "r") as fd:
        as_json = json.load(fd)
        if kd_org in as_json:
            return as_json[kd_org]

    return None



from django.conf import settings

__all__ = []

DEFAULTS = {
    "SSO_UI_URL": "https://sso.ui.ac.id/cas2/",
    "SSO_UI_FORCE_SERVICE_HTTPS": False,
}


for key, value in list(DEFAULTS.items()):
    if not hasattr(settings, key):
        setattr(settings, key, value)



import json

from django.http import HttpResponse, HttpResponseForbidden, HttpResponseRedirect
from django.conf import settings
from django.urls import reverse
from django.views.decorators.csrf import csrf_exempt
from django.views.decorators.http import require_http_methods
from django.contrib.auth.models import User


from .utils import (
    get_cas_client,
    get_service_url,
    authenticate,
    normalize_username,
    get_additional_info,
)


def with_sso_ui(force_login=True):
    def decorator(func):
        def wrapper(request, *args, **kwargs):
            service_url = get_service_url(request)
            client = get_cas_client(service_url)
            login_url = client.get_login_url()

            ticket = request.GET.get("ticket")
            if ticket:
                sso_profile = authenticate(ticket, client)

                if sso_profile is None and force_login:
                    return HttpResponseRedirect(login_url)

                kwargs.update({"sso_profile": sso_profile})
                return func(request, *args, **kwargs)
            else:
                return HttpResponseRedirect(login_url)

        return wrapper

    return decorator



import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
  name = 'fix-sso-ui',         # How you named your package folder (MyLib)
  packages = ['fix_sso_ui'],   # Chose the same as "name"
  version = '1.0.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Forked from https://github.com/RistekCSUI/django-sso-ui originally made by fatanugraha, temp. uploaded fix for public access',   # Give a short description about your library
  author="Fata Nugraha",
  author_email="fatanugraha@outlook.com",
  url = 'https://github.com/stevensim226/django-sso-ui',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/stevensim226/django-sso-ui/archive/refs/tags/v1.0.1.tar.gz',    # I explain this later on
  install_requires=["python-cas", "django", "six"],
  classifiers=[
    "License :: OSI Approved :: MIT License",
    "Programming Language :: Python :: 3",
    "Programming Language :: Python :: 3.6",
  ],
)
